==> StopWatch-20.1.tar.bz2: StopWatch-20.1/README.md <==
What is this?
=============

The StopWatch activity allows you to measure the amount of time something takes.  It shows a number of digital stopwatches.  Each stopwatch is independent.

Features include:

* synchronized collaborative timing through the Sugar collaboration system,
* saving stopwatches to the Journal ... even while they are still running!
* keyboard-navigable, with special accelerators for use on laptops in tablet mode,
* names for stopwatches for easy reference,
* mark-saving for important points during a timed session,
* very high CPU efficiency: uses no CPU time when not visible on-screen.

How to use?
===========

StopWatch is not part of the Sugar desktop, but can be added.  Please refer to;

* [How to Get Sugar on sugarlabs.org](https://sugarlabs.org/),
* [How to use Sugar](https://help.sugarlabs.org/),
* [Download StopWatch using Browse](https://activities.sugarlabs.org/), search for `Turtle StopWatch`, then download, and;
* [How to use StopWatch](https://help.sugarlabs.org/stopwatch.html)

How to upgrade?
===============

On Sugar desktop systems;
* use [My Settings](https://help.sugarlabs.org/en/my_settings.html), [Software Update](https://help.sugarlabs.org/en/my_settings.html#software-update), or;
* use Browse to open [activities.sugarlabs.org](https://activities.sugarlabs.org/), search for `StopWatch`, then download.

How to integrate?
=================

StopWatch depends on Python, [Sugar Toolkit for GTK+ 3](https://github.com/sugarlabs/sugar-toolkit-gtk3), and GTK+ 3.

StopWatch is started by [Sugar](https://github.com/sugarlabs/sugar).

Developers
==========

StopWatch is the original source of, and inspiration for, the codebase that became [Groupthink](http://bemasc.net/~bens/groupthink/).

Stopwatch was previously maintained in a [git repository at OLPC](http://dev.laptop.org/git/activities/stopwatch/)

==> StopWatch-20.2.tar.bz2: StopWatch-20.2/README.md <==
What is this?
=============

The StopWatch activity allows you to measure the amount of time something takes.  It shows a number of digital stopwatches.  Each stopwatch is independent.

Features include:

* synchronized collaborative timing through the Sugar collaboration system,
* saving stopwatches to the Journal ... even while they are still running!
* keyboard-navigable, with special accelerators for use on laptops in tablet mode,
* names for stopwatches for easy reference,
* mark-saving for important points during a timed session,
* very high CPU efficiency: uses no CPU time when not visible on-screen.

How to use?
===========

StopWatch is not part of the Sugar desktop, but can be added.  Please refer to;

* [How to Get Sugar on sugarlabs.org](https://sugarlabs.org/),
* [How to use Sugar](https://help.sugarlabs.org/),
* [Download StopWatch using Browse](https://activities.sugarlabs.org/), search for `StopWatch`, then download, and;
* [How to use StopWatch](https://help.sugarlabs.org/stopwatch.html)

How to upgrade?
===============

On Sugar desktop systems;
* use [My Settings](https://help.sugarlabs.org/en/my_settings.html), [Software Update](https://help.sugarlabs.org/en/my_settings.html#software-update), or;
* use Browse to open [activities.sugarlabs.org](https://activities.sugarlabs.org/), search for `StopWatch`, then download.

How to integrate?
=================

StopWatch depends on Python, [Sugar Toolkit for GTK+ 3](https://github.com/sugarlabs/sugar-toolkit-gtk3), and GTK+ 3.

StopWatch is started by [Sugar](https://github.com/sugarlabs/sugar).

Developers
==========

StopWatch is the original source of, and inspiration for, the codebase that became [Groupthink](http://dev.laptop.org/git/projects/dobject/tree/).

Stopwatch was previously maintained in a [git repository at OLPC](http://dev.laptop.org/git/activities/stopwatch/)
